summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authorwkoszek <wkoszek@FreeBSD.org>2008-06-08 08:56:46 +0000
committerwkoszek <wkoszek@FreeBSD.org>2008-06-08 08:56:46 +0000
commitb063a5a1695fbd3496a6b913ab9db53c361951ed (patch)
tree94f6768094b56be1f86602089a428f96f524dd98 /sys
parent5644710476d005c14983ed14846197690b2d1f99 (diff)
downloadFreeBSD-src-b063a5a1695fbd3496a6b913ab9db53c361951ed.zip
FreeBSD-src-b063a5a1695fbd3496a6b913ab9db53c361951ed.tar.gz
Fix spelling of "virtual".
There should be no visible change. Reviewed by: rink
Diffstat (limited to 'sys')
-rw-r--r--sys/mips/include/pte.h2
-rw-r--r--sys/mips/mips/trap.c8
2 files changed, 5 insertions, 5 deletions
diff --git a/sys/mips/include/pte.h b/sys/mips/include/pte.h
index 809a71f..aa7e839 100644
--- a/sys/mips/include/pte.h
+++ b/sys/mips/include/pte.h
@@ -121,7 +121,7 @@ typedef pt_entry_t *pd_entry_t;
#define vad_to_pfn64(x) ((quad_t)(x) >> PTE_SHIFT) & PTE_FRAME)
#define pfn_to_vad(x) (((x) & PTE_FRAME) << PTE_SHIFT)
-/* User viritual to pte offset in page table */
+/* User virtual to pte offset in page table */
#define vad_to_pte_offset(adr) (((adr) >> PGSHIFT) & (NPTEPG -1))
#define mips_pg_v(entry) ((entry) & PTE_V)
diff --git a/sys/mips/mips/trap.c b/sys/mips/mips/trap.c
index 015a28a..8c32b59 100644
--- a/sys/mips/mips/trap.c
+++ b/sys/mips/mips/trap.c
@@ -140,7 +140,7 @@ void (*machExceptionTable[]) (void)= {
MipsKernGenException, /* coprocessor unusable */
MipsKernGenException, /* arithmetic overflow */
MipsKernGenException, /* trap exception */
- MipsKernGenException, /* viritual coherence exception inst */
+ MipsKernGenException, /* virtual coherence exception inst */
MipsKernGenException, /* floating point exception */
MipsKernGenException, /* reserved */
MipsKernGenException, /* reserved */
@@ -157,7 +157,7 @@ void (*machExceptionTable[]) (void)= {
MipsKernGenException, /* reserved */
MipsKernGenException, /* reserved */
MipsKernGenException, /* reserved */
- MipsKernGenException, /* viritual coherence exception data */
+ MipsKernGenException, /* virtual coherence exception data */
/*
* The user exception handlers.
*/
@@ -210,7 +210,7 @@ char *trap_type[] = {
"coprocessor unusable",
"arithmetic overflow",
"trap",
- "viritual coherency instruction",
+ "virtual coherency instruction",
"floating point",
"reserved 16",
"reserved 17",
@@ -227,7 +227,7 @@ char *trap_type[] = {
"reserved 28",
"reserved 29",
"reserved 30",
- "viritual coherency data",
+ "virtual coherency data",
};
#if !defined(SMP) && (defined(DDB) || defined(DEBUG))
OpenPOWER on IntegriCloud